@@ -395,11 +395,15 @@ class ParsnipModel(nn.Module):
                                 desc="Preprocessing dataset")
 
             # Run on a single core without multiprocessing
-            preprocessed_light_curves = [preprocess_light_curve(lc, self.settings) for
-                                         lc in iterator]
+            preprocessed_light_curves = []
+            for lc in iterator:
+                preprocessed_light_curves.append(
+                    preprocess_light_curve(lc, self.settings, raise_on_invalid=False)
+                )
         else:
             # Run with multiprocessing in multiple threads.
-            func = functools.partial(preprocess_light_curve, settings=self.settings)
+            func = functools.partial(preprocess_light_curve, settings=self.settings,
+                                     raise_on_invalid=False)
 
             with multiprocessing.Pool(self.threads) as p:
                 iterator = p.imap(func, dataset.light_curves, chunksize=chunksize)
@@ -408,6 +412,19 @@ class ParsnipModel(nn.Module):
                                     file=sys.stdout, desc="Preprocessing dataset")
                 preprocessed_light_curves = list(iterator)
 
+        # Check if any light curves failed to process
+        none_count = 0
+        for lc in preprocessed_light_curves:
+            if lc is None:
+                none_count += 1
+        if none_count > 0:
+            print(f"WARNING: Rejecting {none_count}/{len(preprocessed_light_curves)} "
+                  "light curves. Consider using 'parsnip.load_dataset()' or "
+                  "'parsnip.parse_dataset()' to load/parse the dataset and hopefully "
+                  "avoid this.")
+            preprocessed_light_curves = [i for i in preprocessed_light_curves if i is
+                                         not None]
+
         dataset = lcdata.from_light_curves(preprocessed_light_curves)
         return dataset
 
@@ -1337,23 +1354,31 @@ class ParsnipModel(nn.Module):
         predictions = astropy.table.hstack([meta, predictions], 'exact')
 
         # Estimate the absolute luminosity (assuming a zeropoint of 25).
+        # Figure out which light curves we can calculate the luminosity for.
         amplitudes = predictions['amplitude'].copy()
-        amplitude_mask = amplitudes <= 0.
-        amplitudes[amplitude_mask] = 1.
+        amplitude_mask = amplitudes > 0.
+        redshifts = predictions['redshift'].copy()
+        redshift_mask = redshifts > 0.
+        frac_diff = predictions['amplitude_error'] / amplitudes
+        amplitude_error_mask = frac_diff < 1.
+        luminosity_mask = amplitude_mask & redshift_mask & amplitude_error_mask
+
+        # Mask out invalid data for luminosities
+        redshifts[~luminosity_mask] = 1.
+        amplitudes[~luminosity_mask] = 1.
+        frac_diff[~luminosity_mask] = 0.5
+
         luminosity = (
             -2.5*np.log10(amplitudes)
             + 25.
-            - Planck18.distmod(predictions['redshift']).value
+            - Planck18.distmod(redshifts).value
         )
-        luminosity[amplitude_mask] = np.nan
+        luminosity[~luminosity_mask] = np.nan
         predictions['luminosity'] = luminosity
 
         # Luminosity uncertainty
-        frac_diff = predictions['amplitude_error'] / amplitudes
-        frac_diff[amplitude_mask] = 0.5
-        frac_diff[frac_diff > 0.5] = 0.5
         int_mag_err = frac_to_mag(frac_diff)
-        int_mag_err[amplitude_mask] = -1.
+        int_mag_err[~luminosity_mask] = np.nan
         predictions['luminosity_error'] = int_mag_err
 
         # Remove the processing flag.
